==> generator-hap-1.0.0.tgz: package/app/index.js <==
var fs = require('fs'),
    path = require('path'),
    yeoman = require('yeoman-generator'),
    util = require("./util"),
    config = require("./config");

module.exports = yeoman.Base.extend({
    constructor: function() {
        yeoman.Base.apply(this, arguments);

        this.option("archive", {
            desc: "The archive url",
            type: String,
            defaults: ""
        });

        this.option("branch", {
            desc: "The branch name",
            type: String,
            defaults: config.github.branch
        });

        this.option("skip-local-cache", {
            desc: "Skips the local cache",
            type: Boolean,
            defaults: true
        });

        this.option("skip-npm-install", {
            desc: "Skips the installation of npm",
            type: Boolean,
            defaults: false
        });

        this.option("skip-bower-install", {
            desc: "Skips the installation of bower",
            type: Boolean,
            defaults: false
        });

        this.argument('appname', {
            type: String,
            required: false,
            defaults: ""
        });
    },

    initializing: function() {
        util.log("Welcome to use hap.")
    },

    writing: function() {
        var self = this,
            done = this.async(),
            archive = this.options["archive"],
            skipLocalCache = this.options["skip-local-cache"],
            branch = this.options["branch"],
            target = path.join(config.targetPath, this.appname);

        function callback(err, remote){
            var source;
            if (!err) {
                util.log("The branch has been download to " + remote.cachePath);

                util.log("Copy files to " + path.join(process.cwd(), target));

                //copy assets and .* file
                source = [path.join(remote.cachePath, "**"), path.join(remote.cachePath, ".*")];

                self.fs.copy(source, target);

            } else {
                util.log(err);
                process.exit(1);
            }

            done();
        }

        util.log("Downloading the files.");

        //if archive is not empty
        if(archive){
            this.remote(archive, callback, skipLocalCache);
        }else{
            this.remote(config.github.username, config.github.repository, branch, callback, skipLocalCache);
        }
    },
    install: function() {
        var skipNpmInstall = this.options["skip-npm-install"],
            skipBowerInstall = this.options["skip-bower-install"];

        this.installDependencies({
            bower: skipBowerInstall ? false : true,
            npm: skipNpmInstall ? false : true,
            callback: function(err) {
                util.log("The installation of dependencies has been download.");
            }
        });
    }
});

==> generator-hap-1.0.1.tgz: package/app/index.js <==
var fs = require('fs'),
    path = require('path'),
    yeoman = require('yeoman-generator'),
    util = require("./util"),
    config = require("./config");

module.exports = yeoman.Base.extend({
    constructor: function() {
        yeoman.Base.apply(this, arguments);

        this.option("update", {
            desc: "Update scaffold",
            type: Boolean,
            defaults: false
        });

        this.option("archive", {
            desc: "The archive url",
            type: String,
            defaults: ""
        });

        this.option("branch", {
            desc: "The branch name",
            type: String,
            defaults: config.github.branch
        });

        this.option("skip-local-cache", {
            desc: "Skips the local cache",
            type: Boolean,
            defaults: true
        });

        this.option("skip-npm-install", {
            desc: "Skips the installation of npm",
            type: Boolean,
            defaults: false
        });

        this.option("skip-bower-install", {
            desc: "Skips the installation of bower",
            type: Boolean,
            defaults: false
        });

        this.argument('appname', {
            type: String,
            required: false,
            defaults: ""
        });
    },

    initializing: function() {
        util.log("Welcome to use hap.")
    },

    writing: function() {
        var self = this,
            done = this.async(),
            archive = this.options["archive"],
            skipLocalCache = this.options["skip-local-cache"],
            branch = this.options["branch"],
            target = path.join(config.targetPath, this.appname);

        function callback(err, remote){
            var source;
            if (!err) {
                util.log("The branch has been download to " + remote.cachePath);

                util.log("Copy files to " + path.join(process.cwd(), target));

                //copy assets and .* file
                source = [path.join(remote.cachePath, "**"), path.join(remote.cachePath, ".*")];

                self.fs.copy(source, target);

            } else {
                util.log(err);
                process.exit(1);
            }

            done();
        }

        util.log("Downloading the files.");

        //if archive is not empty
        if(archive){
            this.remote(archive, callback, skipLocalCache);
        }else{
            this.remote(config.github.username, config.github.repository, branch, callback, skipLocalCache);
        }
    },
    install: function() {
        var update = this.options["update"],
            skipNpmInstall = this.options["skip-npm-install"],
            skipBowerInstall = this.options["skip-bower-install"];

        !update && this.installDependencies({
            bower: skipBowerInstall ? false : true,
            npm: skipNpmInstall ? false : true,
            callback: function(err) {
                util.log("The installation of dependencies has been download.");
            }
        });
    }
});
